[java-metadata-aggregator COMMIT] /trunk/aggregator-pipeline/src/main/java/net/shibboleth/metadata/dom/saml/GenerateI...

noreply at shibboleth.net noreply at shibboleth.net
Fri Jun 6 14:24:06 EDT 2014


Author: putmanb
Date: Fri Jun  6 14:24:06 2014
New Revision: 372

URL: http://svn.shibboleth.net/view/java-metadata-aggregator?rev=372&view=rev
Log:
Some work on JSPT-45: Implement class and method renames for new naming convention for any remaining components.

Modified:
    trunk/aggregator-pipeline/src/main/java/net/shibboleth/metadata/dom/saml/GenerateIdStage.java

Modified: trunk/aggregator-pipeline/src/main/java/net/shibboleth/metadata/dom/saml/GenerateIdStage.java
URL: http://svn.shibboleth.net/view/java-metadata-aggregator/trunk/aggregator-pipeline/src/main/java/net/shibboleth/metadata/dom/saml/GenerateIdStage.java?rev=372&r1=371&r2=372&view=diff
==============================================================================
--- trunk/aggregator-pipeline/src/main/java/net/shibboleth/metadata/dom/saml/GenerateIdStage.java (original)
+++ trunk/aggregator-pipeline/src/main/java/net/shibboleth/metadata/dom/saml/GenerateIdStage.java Fri Jun  6 14:24:06 2014
@@ -25,7 +25,7 @@
 import net.shibboleth.metadata.pipeline.StageProcessingException;
 import net.shibboleth.utilities.java.support.logic.Constraint;
 import net.shibboleth.utilities.java.support.security.IdentifierGenerationStrategy;
-import net.shibboleth.utilities.java.support.security.Type4UuidIdentifierGenerationStrategy;
+import net.shibboleth.utilities.java.support.security.Type4UUIDIdentifierGenerationStrategy;
 import net.shibboleth.utilities.java.support.xml.AttributeSupport;
 
 import org.w3c.dom.Attr;
@@ -40,9 +40,9 @@
     /** Strategy used to generate identifiers. */
     private final IdentifierGenerationStrategy idGenerator;
 
     /** Constructor. Initialized the {@link #idGenerator} to a {@link Type4UuidIdentifierGenerationStrategy}. */
     public GenerateIdStage() {
-        idGenerator = new Type4UuidIdentifierGenerationStrategy();
+        idGenerator = new Type4UUIDIdentifierGenerationStrategy();
     }
 
     /**
@@ -40,9 +40,9 @@
     private final IdentifierGenerationStrategy idGenerator;
 
-    /** Constructor. Initialized the {@link #idGenerator} to a {@link Type4UuidIdentifierGenerationStrategy}. */
+    /** Constructor. Initialized the {@link #idGenerator} to a {@link Type4UUIDIdentifierGenerationStrategy}. */
     public GenerateIdStage() {



More information about the commits mailing list